@@ -2,7 +2,7 @@ global.ict <- function(x){
 
 	xms <- x$measure
 
-	if(xms=="OR"||xms=="RR"||xms=="RD"||xms=="HR"){
+	if(xms=="OR"||xms=="RR"||xms=="RD"||xms=="HR"||xms=="SPD"){
 
 	study <- x$study
 	treat <- x$treat
